@@ -12,11 +12,11 @@ use version;
 use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
-use TryCatch;
+use Try::Tiny;
 
 extends 'W3C::SOAP::Client';
 
-our $VERSION = version->new('0.07');
+our $VERSION = version->new('0.08');
 
 has header => (
     is        => 'rw',
@@ -35,9 +35,21 @@ sub _request {
     if ( $method->has_in_class && $method->has_in_attribute ) {
         my $class = $method->in_class;
         my $att   = $method->in_attribute;
-        my $xsd   = $class->new(
-            $att => @args == 1 ? $args[0] : {@args},
-        );
+
+        my $att_args = @args == 1 ? $args[0] : {@args};
+
+        my $header_args = delete $att_args->{header} || {};
+
+        my $xsd   = $class->new( $att => $att_args);
+
+        if ( $method->has_in_header_class && $method->has_in_header_attribute) {
+            my $header_class   = $method->in_header_class;
+            my $header_att     = $method->in_header_attribute;
+
+            my $header = $header_class->new($header_att => $header_args);
+
+            $self->header->message($header);
+        }
         my $xsd_ns = $xsd->xsd_ns;
         if ( $xsd_ns !~ m{/$} ) {
             $xsd_ns .= '/';
@@ -112,13 +124,13 @@ sub send {
     try {
         $content = $self->post($action, $xml);
     }
-    catch ($e) {
+    catch  {
         $self->log->error("$action RESPONSE \n" . $self->response->decoded_content) if $self->has_log;
 
         W3C::SOAP::Exception::HTTP->throw(
             faultcode => $self->response->code,
             message   => $self->response->message,
-            error     => $e,
+            error     => $_,
         );
     };
     $self->log->debug("$action RESPONSE \n$content") if $self->has_log;
@@ -185,7 +197,7 @@ W3C::SOAP::WSDL - A SOAP WSDL Client object
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL version 0.07.
+This documentation refers to W3C::SOAP::WSDL version 0.08.
 
 
 =head1 SYNOPSIS
